@@ -126,6 +126,7 @@ class ClbcBase(object):
         else:  # both bpf.c and bo, check hash and version
             with open(bpf_c, "r") as f:
                 s = f.read()
+            s += self._env
             if sys.version_info.major >= 3:
                 cHash = hashlib.sha256(s.encode()).hexdigest()
             else:
@@ -139,6 +140,7 @@ class ClbcBase(object):
         if not oFlag:  # only string
             return True
         else:  # both bpf.c and bo, check hash and version
+            s += self._env
             if sys.version_info.major >= 3:
                 cHash = hashlib.sha256(s.encode()).hexdigest()
             else:
@@ -191,7 +193,6 @@ class ClbcBase(object):
         dRecv = cli.getC(s, self._env)
         if dRecv is None:
             raise Exception("receive error")
-        print(dRecv.keys())
         if dRecv['so'] is None:
             print("compile failed, log is:\n%s" % dRecv['clog'])
             raise InvalidArgsException("compile failed.")
@@ -229,29 +230,13 @@ class ClbcBase(object):
             else:
                 raise InvalidArgsException("bad type: %s, key: %s" % (t, k))
 
-
-class ClbcApp(ClbcBase):
-    def __init__(self, soPath):
-        super(ClbcApp, self).__init__(soPath)
-
-    def _callback(self, cpu, data, size):
+    def getMap(self, name, data, size):
         stream = ct.string_at(data, size)
-        e = self.maps['my_map'].event(stream)
-        print("%d, %s, 0x%x" % (e.pid, e.comm, e.cookie))
-        tbl = self.maps['pids'].get()
-        if len(tbl) > 20:
-            self.maps['pids'].clear()
-        print(self.maps['callStack'].getStacks(e.stack_id, 2))
-
-    def loop(self):
-        self.maps['my_map'].open_perf_buffer(self._callback)
         try:
-            self.maps['my_map'].perf_buffer_poll()
-        except KeyboardInterrupt:
-            print("key interrupt.")
-            exit()
+            return self.maps[name].event(stream)
+        except IndexError:
+            return None
 
 
 if __name__ == "__main__":
-    a = ClbcApp('lbc')
-    a.loop()
\ No newline at end of file
+    pass
\ No newline at end of file
